summaryrefslogtreecommitdiffstats
path: root/chalk/colorspaces/wetsticky
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/colorspaces/wetsticky')
-rw-r--r--chalk/colorspaces/wetsticky/ws/canvas.c24
-rw-r--r--chalk/colorspaces/wetsticky/ws/canvas.h4
-rw-r--r--chalk/colorspaces/wetsticky/ws/engine.c2
-rw-r--r--chalk/colorspaces/wetsticky/ws/engine3.c2
-rw-r--r--chalk/colorspaces/wetsticky/ws/ogl_interface.c2
-rw-r--r--chalk/colorspaces/wetsticky/ws/x_interface.c2
6 files changed, 18 insertions, 18 deletions
diff --git a/chalk/colorspaces/wetsticky/ws/canvas.h b/chalk/colorspaces/wetsticky/ws/canvas.h
index 2df50140..57453e7b 100644
--- a/chalk/colorspaces/wetsticky/ws/canvas.h
+++ b/chalk/colorspaces/wetsticky/ws/canvas.h
@@ -22,11 +22,11 @@ Wet and Sticky is free software; you can redistribute it and/or modify it under
extern int number_of_repaints_needed();
/* Returns the number of cells needing to repainted. */
-extern void need_to_repaint (/* POINT */);
+extern void need_to_tqrepaint (/* POINT */);
/* Requests that the cell at the given point be repainted
at the next update as it has been modified. */
-extern void next_cell_for_repaint (/* *CELL_PTR, POINT_PTR */);
+extern void next_cell_for_tqrepaint (/* *CELL_PTR, POINT_PTR */);
/* Returns a pointer to a cell that needs to be updated as well
as the location of that cell on the canvas. If there are
no more cells to be redrawn then the pointer will be NIL. */
diff --git a/chalk/colorspaces/wetsticky/ws/engine.c b/chalk/colorspaces/wetsticky/ws/engine.c
index 19097d9f..b3855bda 100644
--- a/chalk/colorspaces/wetsticky/ws/engine.c
+++ b/chalk/colorspaces/wetsticky/ws/engine.c
@@ -192,7 +192,7 @@ int amount;
}
- need_to_repaint(destLocus);
+ need_to_tqrepaint(destLocus);
}
/* *********************************************************************** */
diff --git a/chalk/colorspaces/wetsticky/ws/engine3.c b/chalk/colorspaces/wetsticky/ws/engine3.c
index 03a7d4f3..fceb0c05 100644
--- a/chalk/colorspaces/wetsticky/ws/engine3.c
+++ b/chalk/colorspaces/wetsticky/ws/engine3.c
@@ -191,7 +191,7 @@ int amount;
}
- need_to_repaint(destLocus);
+ need_to_tqrepaint(destLocus);
}
/* *********************************************************************** */
diff --git a/chalk/colorspaces/wetsticky/ws/ogl_interface.c b/chalk/colorspaces/wetsticky/ws/ogl_interface.c
index 76a552a9..953b10c8 100644
--- a/chalk/colorspaces/wetsticky/ws/ogl_interface.c
+++ b/chalk/colorspaces/wetsticky/ws/ogl_interface.c
@@ -255,7 +255,7 @@ void evolve_paint()
for (k=0; k < STEP_LIMIT; k++) single_step();
while (TRUE) {
- next_cell_for_repaint(&cell, &p);
+ next_cell_for_tqrepaint(&cell, &p);
if (cell == NIL) return;
paint_cell(cell, p.x, p.y);
glFlush();
diff --git a/chalk/colorspaces/wetsticky/ws/x_interface.c b/chalk/colorspaces/wetsticky/ws/x_interface.c
index f4cb4901..7c36a303 100644
--- a/chalk/colorspaces/wetsticky/ws/x_interface.c
+++ b/chalk/colorspaces/wetsticky/ws/x_interface.c
@@ -700,7 +700,7 @@ void evolve_paint()
for (k=0; k < STEP_LIMIT; k++) single_step();
while (TRUE) {
- next_cell_for_repaint(&cell, &p);
+ next_cell_for_tqrepaint(&cell, &p);
if (cell == NIL) return;
paint_cell(cell, p.x, p.y);
}
diff --git a/chalk/colorspaces/wetsticky/ws/canvas.c b/chalk/colorspaces/wetsticky/ws/canvas.c
index d2e27cd1..d6940294 100644
--- a/chalk/colorspaces/wetsticky/ws/canvas.c
+++ b/chalk/colorspaces/wetsticky/ws/canvas.c
@@ -31,13 +31,13 @@ CELL canvas[CANVAS_WIDTH][CANVAS_HEIGHT];
/* This module maintains a list of the addresses of cells that have
been modified since the last redraw and therefore need updating.
- Points are added to this list by the need_to_repaint() routine
- and are removed by the next_cell_for_repaint() function. The
+ Points are added to this list by the need_to_tqrepaint() routine
+ and are removed by the next_cell_for_tqrepaint() function. The
pointer to the current tail of the list is updated by side-effect. */
static POINT need_repainting[REDRAW_LIMIT];
static int next_free = 0;
-static int next_to_repaint = 0;
+static int next_to_tqrepaint = 0;
/* *********************************************************************** */
@@ -50,7 +50,7 @@ int number_of_repaints_needed()
/* *********************************************************************** */
-void need_to_repaint(point)
+void need_to_tqrepaint(point)
/* The cell at this location needs to be redrawn since it has
been altered. Scan the list to see if it is already
scheduled for a repainting operation and only add it if
@@ -62,7 +62,7 @@ POINT point;
int k;
/* If the list is already full then simply ignore the repaint
request - it will get done eventually anyway. */
if (next_free == REDRAW_LIMIT) return;
@@ -85,7 +85,7 @@ POINT point;
/* *********************************************************************** */
-void next_cell_for_repaint(cell, locus)
+void next_cell_for_tqrepaint(cell, locus)
/* This routine returns the next cell to be repainted, together with its
location on the canvas. This is determined by taking the next point
from the need_repainting list and accessing its cell. If the list is
@@ -97,16 +97,16 @@ void next_cell_for_repaint(cell, locus)
POINT_PTR locus;
{
- if (next_to_repaint >= next_free) {
- next_to_repaint = next_free = 0;
+ if (next_to_tqrepaint >= next_free) {
+ next_to_tqrepaint = next_free = 0;
*(cell) = NIL;
return;
}
- *(cell) = get_cell(need_repainting[next_to_repaint]);
- locus->x = need_repainting[next_to_repaint].x;
- locus->y = need_repainting[next_to_repaint].y;
- next_to_repaint++;
+ *(cell) = get_cell(need_repainting[next_to_tqrepaint]);
+ locus->x = need_repainting[next_to_tqrepaint].x;
+ locus->y = need_repainting[next_to_tqrepaint].y;
+ next_to_tqrepaint++;
}
/* *********************************************************************** */
@@ -62,7 +62,7 @@ POINT point;
int k;
- /* If the list is already full then simply ignore the repaint
+ /* If the list is already full then simply ignore the tqrepaint
request - it will get done eventually anyway. */
if (next_free == REDRAW_LIMIT) return;